@@ -1,6 +1,6 @@
 package Catalyst::View::ByCode::Renderer;
 {
-  $Catalyst::View::ByCode::Renderer::VERSION = '0.18';
+  $Catalyst::View::ByCode::Renderer::VERSION = '0.19';
 }
 use strict;
 use warnings;
@@ -32,18 +32,19 @@ our %EXPORT_TAGS = (
 our @IS_KNOWN = (
     # HTML5 tags not defined in HTML::Tagset
     qw( article aside audio
-        canvas command
-        datalist details
+        bdi bdo
+        canvas
+        data datalist details dialog
         figcaption figure footer
-        header hgroup
+        header
         keygen
-        markup meter
+        main mark markup menu menuitem meter
         nav
         output
         progress
-        rt ruby
+        rd rp rt ruby
         section source summary
-        time
+        time track
         video ),
     grep { m{\A \w}xms }
     keys(%HTML::Tagset::isKnown)
@@ -258,6 +259,8 @@ sub _render {
 
                                 if ($k eq 'disabled' ||
                                     $k eq 'checked'  ||
+                                    $k eq 'hidden'   ||
+                                    $k eq 'inert'    ||
                                     $k eq 'multiple' ||
                                     $k eq 'readonly' ||
                                     $k eq 'selected' ||
